@@ -1,6 +1,6 @@
 <?php
 /*
- * This file is part of the Comparator package.
+ * This file is part of sebastian/comparator.
  *
  * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
@@ -10,19 +10,18 @@
 
 namespace SebastianBergmann\Comparator;
 
+use PHPUnit\Framework\TestCase;
 use SplObjectStorage;
 use stdClass;
 
 /**
  * @coversDefaultClass SebastianBergmann\Comparator\SplObjectStorageComparator
  *
- * @package    Comparator
- * @author     Jeff Welch <whatthejeff@gmail.com>
- * @copyright  Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.github.com/sebastianbergmann/comparator
+ * @uses SebastianBergmann\Comparator\Comparator
+ * @uses SebastianBergmann\Comparator\Factory
+ * @uses SebastianBergmann\Comparator\ComparisonFailure
  */
-class SplObjectStorageComparatorTest extends \PHPUnit_Framework_TestCase
+class SplObjectStorageComparatorTest extends TestCase
 {
     private $comparator;
 
@@ -33,11 +32,11 @@ class SplObjectStorageComparatorTest extends \PHPUnit_Framework_TestCase
 
     public function acceptsFailsProvider()
     {
-        return array(
-          array(new SplObjectStorage, new stdClass),
-          array(new stdClass, new SplObjectStorage),
-          array(new stdClass, new stdClass)
-        );
+        return [
+          [new SplObjectStorage, new stdClass],
+          [new stdClass, new SplObjectStorage],
+          [new stdClass, new stdClass]
+        ];
     }
 
     public function assertEqualsSucceedsProvider()
@@ -56,12 +55,12 @@ class SplObjectStorageComparatorTest extends \PHPUnit_Framework_TestCase
         $storage4->attach($object2);
         $storage4->attach($object1);
 
-        return array(
-          array($storage1, $storage1),
-          array($storage1, $storage2),
-          array($storage3, $storage3),
-          array($storage3, $storage4)
-        );
+        return [
+          [$storage1, $storage1],
+          [$storage1, $storage2],
+          [$storage3, $storage3],
+          [$storage3, $storage4]
+        ];
     }
 
     public function assertEqualsFailsProvider()
@@ -78,11 +77,11 @@ class SplObjectStorageComparatorTest extends \PHPUnit_Framework_TestCase
         $storage3->attach($object2);
         $storage3->attach($object1);
 
-        return array(
-          array($storage1, $storage2),
-          array($storage1, $storage3),
-          array($storage2, $storage3),
-        );
+        return [
+          [$storage1, $storage2],
+          [$storage1, $storage3],
+          [$storage2, $storage3],
+        ];
     }
 
     /**
@@ -119,9 +118,7 @@ class SplObjectStorageComparatorTest extends \PHPUnit_Framework_TestCase
 
         try {
             $this->comparator->assertEquals($expected, $actual);
-        }
-
-        catch (ComparisonFailure $exception) {
+        } catch (ComparisonFailure $exception) {
         }
 
         $this->assertNull($exception, 'Unexpected ComparisonFailure');
@@ -133,10 +130,20 @@ class SplObjectStorageComparatorTest extends \PHPUnit_Framework_TestCase
      */
     public function testAssertEqualsFails($expected, $actual)
     {
-        $this->setExpectedException(
-          'SebastianBergmann\\Comparator\\ComparisonFailure',
-          'Failed asserting that two objects are equal.'
-        );
+        $this->expectException(ComparisonFailure::class);
+        $this->expectExceptionMessage('Failed asserting that two objects are equal.');
+
         $this->comparator->assertEquals($expected, $actual);
     }
+
+    public function testAssertEqualsFails2()
+    {
+        $this->expectException(ComparisonFailure::class);
+        $this->expectExceptionMessage('Failed asserting that two objects are equal.');
+
+        $t = new SplObjectStorage();
+        $t->attach(new \stdClass());
+
+        $this->comparator->assertEquals($t, new \SplObjectStorage());
+    }
 }
