@@ -1,6 +1,6 @@
 <?php
 /*
- * This file is part of the Comparator package.
+ * This file is part of sebastian/comparator.
  *
  * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
@@ -10,18 +10,17 @@
 
 namespace SebastianBergmann\Comparator;
 
+use PHPUnit\Framework\TestCase;
 use stdClass;
 
 /**
  * @coversDefaultClass SebastianBergmann\Comparator\TypeComparator
  *
- * @package    Comparator
- * @author     Jeff Welch <whatthejeff@gmail.com>
- * @copyright  Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.github.com/sebastianbergmann/comparator
+ * @uses SebastianBergmann\Comparator\Comparator
+ * @uses SebastianBergmann\Comparator\Factory
+ * @uses SebastianBergmann\Comparator\ComparisonFailure
  */
-class TypeComparatorTest extends \PHPUnit_Framework_TestCase
+class TypeComparatorTest extends TestCase
 {
     private $comparator;
 
@@ -32,40 +31,40 @@ class TypeComparatorTest extends \PHPUnit_Framework_TestCase
 
     public function acceptsSucceedsProvider()
     {
-        return array(
-          array(true, 1),
-          array(false, array(1)),
-          array(null, new stdClass),
-          array(1.0, 5),
-          array("", "")
-        );
+        return [
+          [true, 1],
+          [false, [1]],
+          [null, new stdClass],
+          [1.0, 5],
+          ['', '']
+        ];
     }
 
     public function assertEqualsSucceedsProvider()
     {
-        return array(
-          array(true, true),
-          array(true, false),
-          array(false, false),
-          array(null, null),
-          array(new stdClass, new stdClass),
-          array(0, 0),
-          array(1.0, 2.0),
-          array("hello", "world"),
-          array("", ""),
-          array(array(), array(1,2,3))
-        );
+        return [
+          [true, true],
+          [true, false],
+          [false, false],
+          [null, null],
+          [new stdClass, new stdClass],
+          [0, 0],
+          [1.0, 2.0],
+          ['hello', 'world'],
+          ['', ''],
+          [[], [1,2,3]]
+        ];
     }
 
     public function assertEqualsFailsProvider()
     {
-        return array(
-          array(true, null),
-          array(null, false),
-          array(1.0, 0),
-          array(new stdClass, array()),
-          array("1", 1)
-        );
+        return [
+          [true, null],
+          [null, false],
+          [1.0, 0],
+          [new stdClass, []],
+          ['1', 1]
+        ];
     }
 
     /**
@@ -89,9 +88,7 @@ class TypeComparatorTest extends \PHPUnit_Framework_TestCase
 
         try {
             $this->comparator->assertEquals($expected, $actual);
-        }
-
-        catch (ComparisonFailure $exception) {
+        } catch (ComparisonFailure $exception) {
         }
 
         $this->assertNull($exception, 'Unexpected ComparisonFailure');
@@ -103,7 +100,9 @@ class TypeComparatorTest extends \PHPUnit_Framework_TestCase
      */
     public function testAssertEqualsFails($expected, $actual)
     {
-        $this->setExpectedException('SebastianBergmann\\Comparator\\ComparisonFailure', 'does not match expected type');
+        $this->expectException(ComparisonFailure::class);
+        $this->expectExceptionMessage('does not match expected type');
+
         $this->comparator->assertEquals($expected, $actual);
     }
 }
